@@ -1,6 +1,6 @@
 ## RcppDataFrame.R: DataFrame example
 ##
-## Copyright (C) 2011 - 2016  Dirk Eddelbuettel and Romain Francois
+## Copyright (C) 2011 - 2017  Dirk Eddelbuettel and Romain Francois
 ##
 ## This file is part of RcppExamples.
 ##
@@ -34,5 +34,5 @@ RcppDataFrame <- function() {
     cat("\nAfter call, original and new data frames:\n")
     print(val)
 
-    val
+    invisible(val)
 }
